@@ -173,12 +173,13 @@ def main(args=None):
             
 # C.1.ii) Netcdf file        
             try:
-                dir_out = os.path.join(cfg.scc['output-dir'],meas_id)
+                dir_out = cfg.scc['output-dir']
                 geom_dts = \
                     export_nc(geom, metadata = metadata[i], alpha = alphas[i], 
                               wave = wave[i], snr_factor = snr_factor[i], 
                               wct_peak_margin = wct_peak_margin[i], 
-                              fname = fname, dir_out = dir_out)
+                              ltool_ver = __version__, fname = fname, 
+                              dir_out = dir_out)
             except Exception as e:
                 logger.error("Error while creating the netcdf files ")
                 sys.exit(9)
